@@ -4,5 +4,5 @@ WMS_PROTOCOL = "OGC:WMS"
 WCS_PROTOCOL = "OGC:WCS"
 WMTS_PROTOCOL = "OGC:WMTS"
 ATOM_PROTOCOL = "INSPIRE Atom"
-
-PROTOCOLS = [WFS_PROTOCOL, WMS_PROTOCOL, WCS_PROTOCOL, WMTS_PROTOCOL, ATOM_PROTOCOL]
+OAT_PROTOCOL = "OGC:API tiles"
+PROTOCOLS = [WFS_PROTOCOL, WMS_PROTOCOL, WCS_PROTOCOL, WMTS_PROTOCOL, ATOM_PROTOCOL, OAT_PROTOCOL]
